package watch

import (
	"gitlab.schukai.com/oss/utilities/conan/configuration"
	"gitlab.schukai.com/oss/utilities/conan/constants"
	"path"
)

func getScriptName() string {
	return "app.js"
}
func getStyleName() string {
	return "app.css"
}

func newDataset(appID string) *Dataset {

	webPath := configuration.GetServerWebPath()

	scriptName := getScriptName()
	relScriptPath := path.Join(appID, constants.AppScriptDirectory)
	absScriptPath := path.Join(webPath, relScriptPath)
	scriptHash := GetFileHash(path.Join(absScriptPath, scriptName))
	relScriptPath = path.Join("/", relScriptPath, scriptHash, scriptName)

	styleName := getStyleName()
	relStylePath := path.Join(appID, constants.AppStyleDirectory)
	absStylePath := path.Join(webPath, relStylePath)
	styleHash := GetFileHash(path.Join(absStylePath, styleName))
	relStylePath = path.Join("/", relStylePath, styleHash, styleName)

	manifestPath := path.Join("/", appID, constants.WebManifestName)
	faviconPath := path.Join("/", appID, constants.FaviconName)

	tags := &Tags{
		Config:      "",
		WebManifest: "<link rel=\"manifest\" href=\"" + manifestPath + "\" crossorigin=\"use-credentials\">",
		Favicon:     "<link rel=\"icon\" href=\"" + faviconPath + "\">",
		Script:      "<script type=\"module\" src=\"" + relScriptPath + "\"></script>",
		Style:       "<link rel=\"stylesheet\" href=\"" + relStylePath + "\">",
		Cache:       "<meta http-equiv=\"cache-control\" content=\"" + constants.StandardCacheControl + "\">",
	}

	meta := &Meta{
		Language: "en",
	}

	dataset := &Dataset{
		Mnemonic: appID,
		Tags:     tags,
		Meta:     meta,
	}

	return dataset

}

type Meta struct {
	Language string
}

type Resources struct {
	Script string
	Style  string
}

type Tags struct {
	Config      string
	WebManifest string
	Favicon     string
	Script      string
	Style       string
	Cache       string
}

type Dataset struct {
	Mnemonic string
	*Tags
	*Meta
	*Resources
}
